# Generated by roxygen2: do not edit by hand

export(functional_calibration_splines)
export(functional_calibration_wavelets)
export(plot_aggregated_curve)
export(weight_estimation)
importFrom(grDevices,recordPlot)
importFrom(splines,bs)
importFrom(stats,coef)
importFrom(stats,dnorm)
importFrom(stats,integrate)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,rnorm)
importFrom(wavethresh,threshold)
importFrom(wavethresh,wd)
importFrom(wavethresh,wr)
